package ch.iet_gibb.heatcalculatorfx.model;


/**
 * Software zur Erstellung von kubischen Wärmespeicher
 * @author Benedikt Schwiede
 * @version 1.0.1
 * @since 04.03.2025
 */
public class CuboidHeatstorage extends GeneralHeatstorage{
    /** Hohe des Wärmespeichers */
    private float height;
    /** Breite des Wärmespeichers */
    private float width;
    /** Tiefe des Wärmespeichers */
    private float depth;

    /** Konstruktor von CuboidHeatstorage */
     public CuboidHeatstorage() {}

    /** Konstruktor von CuboidHeatstorage
     * @param name
     * @param height
     * @param width
     * @param depth
     * @param temperature
     * @param requiredEnergyPerDay */
    public CuboidHeatstorage(String name, float height, float width, float depth, float temperature, float requiredEnergyPerDay) {
        super(name, calculateVolumeWithHeightWidthAndDepth(height, width, depth), temperature, requiredEnergyPerDay);
        this.height = checkValue(0, height);
        this.width = checkValue(0, width);
        this.depth = checkValue(0, depth);
        this.properties.add(new Property("Height", String.valueOf(height), "float"));
        this.properties.add(new Property("Width", String.valueOf(width), "float"));
        this.properties.add(new Property("Depth", String.valueOf(depth), "float"));
    }

    /**
     * @return Höhe des Wärmespeichers
     */
    public float getHeight() {
        return height;
    }

    /**
     * @param height Höhe des Wärmespeichers
     */
    public void setHeight(float height) {
        this.height = checkValue(0, height);
    }

    /**
     * @return Breite des Wäremspeichers
     */
    public float getWidth() {
        return width;
    }

    /**
     * @param width Breite des Wäremspeichers
     */
    public void setWidth(float width) {
        this.width = checkValue(0, width);
    }

    /**
     * @return Tiefe des Wärmespeichers
     */
    public float getDepth() {
        return depth;
    }

    /**
     * @param depth Tiefe des Wärmespeichers
     */
    public void setDepth(float depth) {
        this.depth = checkValue(0, depth);
    }

    @Override
    public String toString() {
        return "Name: " + name
                + "\nVolume: " + (height * depth * width / 1000) + " Liters"
                + "\nHeight: " + height + " cm"
                + "\nWidth: " + width + " cm"
                + "\nDepth: " + depth + " cm"
                + "\nTemperature: " + temperature + " Celsius"
                + "\nStored energy: " + getStoredEnergy() + " kWh"
                + "\nRequired energy: " + requiredEnergyPerDay + " kWh"
                + "\nRemaining days of energy: " + getRemainingDaysOfEnergy() + " Days";
    }
}
