package ch.iet_gibb.heatcalculatorfx.model;


/**
 * Software zur Erstellung von zylindrischen Wärmespeicher
 *
 * @author Benedikt Schwiede
 * @version 1.0.1
 * @since 04.03.2025
 */
public class CylindricalHeatstorage extends GeneralHeatstorage {
    /**
     * Höhe des Wärmespeichers
     */
    private float height;
    /**
     * Durchmesser des Wäremspeichers
     */
    private float diameter;

    /**
     * Konstruktor von CylindricalHeatstorage
     */
    public CylindricalHeatstorage() {
    }

    /**
     * Konstruktor von CylindricalHeatstorage
     *
     * @param name
     * @param height
     * @param diameter
     * @param temperature
     * @param requiredEnergyPerDay
     */
    public CylindricalHeatstorage(String name, float height, float diameter, float temperature, float requiredEnergyPerDay) {
        super(name, calculateVolumeWithDiameterAndHeight(diameter, height), temperature, requiredEnergyPerDay);
        this.height = checkValue(0, height);
        this.diameter = checkValue(0, diameter);
        this.properties.add( new Property("Height", String.valueOf(height), "float"));
        this.properties.add( new Property("Diameter", String.valueOf(diameter), "float"));
    }

    /**
     * @return Höhe des Wärmespeichers
     */
    public float getHeight() {
        return height;
    }

    /**
     * @param height Höhe des Wärmespeichers
     */
    public void setHeight(float height) {
        this.height = checkValue(0, height);
    }

    /**
     * @return Durchmesser des Wärmespeichers
     */
    public float getDiameter() {
        return diameter;
    }

    /**
     * @param diameter Durchmesser des Wärmespeichers
     */
    public void setDiameter(float diameter) {
        this.diameter = checkValue(0, diameter);
    }

    @Override
    public String toString() {
        return "Name: " + name
                + "\nVolume: " + (Math.PI * Math.pow((diameter / 2), 2) * height / 1000) + " Liters"
                + "\nHeight: " + height + " cm"
                + "\nDiameter: " + diameter + " cm"
                + "\nTemperature: " + temperature + " Celsius"
                + "\nStored energy: " + getStoredEnergy() + " kWh"
                + "\nRequired energy: " + requiredEnergyPerDay + " kWh"
                + "\nRemaining days of energy: " + getRemainingDaysOfEnergy() + " Days";
    }
}
